import subprocess
def Venv():
    subprocess.run('python -m venv venv', shell=True) 
    
def Install(module_list):
    for module in module_list:
        subprocess.run(f'pip install {module}', shell=True)



from setuptools import setup

setup(name='sasvenv',
      version='0.3',
      description='Модуль для более быстрого создания venv',
      packages=['sasvenv'],
      author_email='kassas20@mail.ru',
      zip_safe=False)